# This library based on html from https://pypi.org/project/html/

For documentation please "pydoc html". The same documentation is available
at http://pypi.python.org/pypi/html3

To run its tests use "python -m html".

To install under Python 3:

% python3 setup.py build install
